@@ -50,11 +50,14 @@
 #include <cc++/socket.h>
 #endif
 
+#define	BAYONNE_RELEASE	1		// release check sequence
 #define	NO_TIMESLOT	0xffff
 #define	MAX_DTMF	32
 #define	MAX_LIST	256
 #define	MAX_LIBINPUT	256
 #define	MAX_PATHNAME	256
+#define	MIN_AUDIOFEED	(120 * 8)	// 120 millisecond starting
+#define	MAX_AUDIOFEED	(600 * 8)	// 600 millisecond buffer
 
 #ifdef	WIN32
 #define	PFD_INVALID	INVALID_HANDLE_VALUE
@@ -199,6 +202,7 @@ public:
 		STATE_HOLD,
 		STATE_RECALL,
 		STATE_TONE,
+		STATE_DTMF,
 		STATE_PLAY,
 		STATE_RECORD,
 		STATE_JOIN,
@@ -414,6 +418,7 @@ public:
 		AUDIO_BUFFER,
 		TONE_IDLE,
 		DTMF_KEYDOWN,
+		DTMF_KEYSYNC,	/* timing sync event */
 		DTMF_KEYUP,
 		TONE_START,
 		TONE_STOP,
@@ -529,6 +534,7 @@ public:
 				const char *logstate;
 			}	debug;
 
+			const char *name;
 			const char *errmsg;
 			BayonneSession *pid;
 			BayonneSession *peer;
@@ -627,6 +633,8 @@ public:
 				bool dialing;
 				bool exiting;
 				bool dtmf;
+				char *syncdigit;
+				timeout_t synctimer;
 				timeout_t duration;
 				char digits[64];
 				char sessionid[16];
@@ -833,9 +841,67 @@ public:
          */
         static bool loadMonitor(const char *path);  
 
+	/**
+	 * Load a bgm/audio processing module for continues audio.
+	 *
+	 * @param id of plugin.
+	 * @return true if successful.
+	 */
+	static bool loadAudio(const char *path);
+
 	static void errlog(const char *level, const char *fmt, ...); 
 };
 
+/**
+ * A core class to support audio feeds that can be used in continues
+ * audio processing, whether to feed background music, or other audio
+ * source overlays.
+ */
+class __EXPORT BayonneFeeder : public Audio, protected ThreadLock
+{
+protected:
+	static BayonneFeeder *first;
+	BayonneFeeder *next;
+
+	Sample buffer[MAX_AUDIOFEED];
+	const char *id;
+	unsigned pos, last;
+	unsigned count;
+	bool active;
+
+	void setEnding(void);
+
+	Linear putBuffer(unsigned size);
+
+public:
+	BayonneFeeder(const char *name);
+
+	/**
+	 * Get if encoding is native or not.
+	 *
+	 * @return true if native endian, else linear former...
+	 */
+	virtual bool isNative(void) = 0;
+
+	/**
+	 * Get last position to use.
+	 *
+	 * @return offset for getBuffer work...
+	 */
+	unsigned getPosition(void);
+
+	/**
+	 * Get a buffer for our offset.
+	 *
+	 * @param offset.
+	 * @param size we request.
+	 * @return first sample or NULL if inactive.
+	 */
+	Linear getBuffer(unsigned offset, unsigned size);
+
+	static BayonneFeeder *get(const char *id);
+};
+
 /**
  * A core class to support language translation services in Bayonne
  * phrasebook.
@@ -1565,6 +1631,14 @@ public:
 	 * @return true if reachable
 	 */
 	virtual bool getDestination(const char *target, const char *dial, char *buffer, size_t size);
+
+	/**
+	 * Get available timeslots.
+	 *
+	 * @return available slots.
+	 */
+	inline unsigned getAvail(void)
+		{return avail;}
 };	
 
 /**
@@ -1661,6 +1735,14 @@ public:
 	 */
 	inline BayonneDriver *getDriver(void)
 		{return driver;};
+
+	/**
+	 * Get number of call slots still available.
+	 *
+	 * @return count of call slots available.
+	 */
+	inline unsigned getAvail(void)
+		{return count - used;}
 };
 
 /**
@@ -1752,6 +1834,14 @@ protected:
 	 */
 	virtual void disableDTMF(void);
 
+	/**
+	 * Set continues audio feed if allowed.
+	 *
+	 * @param feed to set or NULL to clear.
+	 * @return true if successful.
+	 */
+	virtual bool setFeeder(BayonneFeeder *feeder);
+
 	/**
 	 * Check audio properties for file and channel audio processing
 	 * based on the driver specific capabilities of this channel
@@ -1781,6 +1871,7 @@ protected:
 	virtual bool enterSeize(Event *event);
 	virtual bool enterHangup(Event *event);
 	virtual bool enterTone(Event *event);
+	virtual bool enterDTMF(Event *event);
 	virtual bool enterPlay(Event *event);
 	virtual bool enterRecord(Event *event);
 	virtual bool enterJoin(Event *event);
@@ -1828,6 +1919,7 @@ protected:
 	bool stateHold(Event *event);
 	bool stateRecall(Event *event);
 	bool stateTone(Event *event);
+	bool stateDTMF(Event *event);
 	bool statePlay(Event *event);
 	bool stateRecord(Event *event);
 	bool stateJoin(Event *event);
@@ -2035,7 +2127,7 @@ public:
 	 * @return driver object.
 	 */
 	inline BayonneDriver *getDriver(void)
-		{return driver;};
+		{return driver;}
 
 	/**
 	 * Return time remaining until timer expires.  Commonly used for
