@@ -844,6 +844,65 @@ bool BayonneSession::stateTone(Event *event)
 	return enterCommon(event);
 }
 
+bool BayonneSession::stateDTMF(Event *event)
+{
+	Event ev;
+
+	if(event->id != TIMER_EXPIRED)
+		if(enterDTMF(event))
+			return true;
+
+	switch(event->id)
+	{
+	case ENTER_STATE:
+		state.tone.flashing = false;
+		if(!state.tone.syncdigit || !*state.tone.syncdigit)
+			return true;
+		if(!state.tone.synctimer || state.tone.synctimer == TIMEOUT_INF)
+			return true;
+	case TIMER_EXPIRED:
+		if(!*state.tone.syncdigit)
+			return true;
+		memset(&ev, 0, sizeof(ev));
+		ev.id = DTMF_KEYSYNC;
+		ev.dtmf.duration = state.tone.synctimer / 2;
+		ev.dtmf.digit = *state.tone.syncdigit - '0';
+		enterDTMF(&ev);				
+		++state.tone.syncdigit;
+		startTimer(state.tone.synctimer);
+		return true;
+	case AUDIO_IDLE:
+		if(state.tone.exiting)
+		{
+			setState(STATE_HANGUP);
+			return true;
+		}
+		if(setLibreset(RESULT_COMPLETE))
+			return true;
+
+		advance();
+		setRunning();
+		return true;
+	case LINE_HANGUP:
+		if(state.tone.flashing)
+			return false;
+		break;
+	case START_FLASH:
+		state.tone.flashing = true;
+		setOffhook(false);
+		break;
+	case STOP_FLASH:
+		setOffhook(true);
+		state.tone.flashing = false;
+		break;
+	case TONE_START:
+		return false;
+	}
+
+	return enterCommon(event);
+}
+
+
 bool BayonneSession::stateConnect(Event *event)
 {
 	Event cancel;
@@ -2065,6 +2124,11 @@ bool BayonneSession::enterTone(Event *event)
         return false;
 }
 
+bool BayonneSession::enterDTMF(Event *event)
+{
+	return enterTone(event);
+}
+
 bool BayonneSession::enterPlay(Event *event)
 {
         return false;
