@@ -312,6 +312,8 @@ void Driver::startDriver(void)
 			rtp_port += 10;
 	}
 
+	eXosip_automatic_action();
+
 #else
 	while(eXosip_init(NULL, NULL, sip_port))
 	{
@@ -486,7 +488,11 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	char *uri;
 	long mult = 60000;
 
-	if(!ScriptChecks::useKeywords(line, "=uri=timeout=server=proxy=userid=secret=type=realm"))
+#ifdef	HAVE_EXOSIP2
+	  osip_message_t *msg = NULL; 
+#endif
+
+	if(!ScriptChecks::useKeywords(line, "=uri=timeout=server=proxy=userid=secret=type=realm=dtmf"))
 		return "invalid keywords for sip, use uri, timeout, proxy, userid, secret, port";
 
 	reg->active = false;
@@ -498,6 +504,13 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	reg->secret = ScriptChecks::findKeyword(line, "secret");
 	reg->realm = ScriptChecks::findKeyword(line, "realm");
 	reg->type = ScriptChecks::findKeyword(line, "type");
+	reg->dtmf = ScriptChecks::findKeyword(line, "dtmf");
+
+	if(!reg->dtmf)
+		reg->dtmf = getLast("dtmf");
+
+	if(!reg->dtmf)
+		reg->dtmf = "auto";
 
 	if(!reg->type)
 		reg->type = getLast("peering");
@@ -602,19 +615,11 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 
 	eXosip_lock();
 
-/*
-	if(reg->userid)
-	{
-		setString(buf, sizeof(buf), reg->userid);
-		p = strchr(buf, '@');
-		if(p)
-			*(p++) = 0;
-
-		if(eXosip_add_authentication_info(buf, buf, reg->secret, NULL, reg->realm))
-			slog.error("sip cannot authenticate with %s", reg->userid);			
-	}
-*/
+#ifdef	HAVE_EXOSIP2
+	reg->regid = eXosip_register_build_initial_register((char *)reg->uri, (char *)reg->proxy, (char *)reg->contact, reg->duration / 1000, &msg);
+#else
 	reg->regid = eXosip_register_init((char *)reg->uri, (char *)reg->proxy, (char *)reg->contact);
+#endif
 
 	if(reg->regid < 0)
 	{
@@ -622,11 +627,33 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 		return "cannot create sip registration";
 	}
 
+#ifdef	HAVE_EXOSIP2
+	osip_message_set_supported(msg, "path");   
+
+	cp = getLast("transport");
+	if(!stricmp(cp, "tcp"))
+		eXosip_transport_set(msg, "TCP"); 
+	else if(!stricmp(cp, "tls"))
+		eXosip_transport_set(msg, "TLS");
+
+/*
+	reg->route = ScriptChecks::findKeyword(line, "route");
+	if(reg->route && reg->route[0])
+	{
+		char *hdr = osip_strdup(reg->route);
+		osip_message_set_multiple_header(msg, hdr, reg->route);
+		osip_free(hdr);
+	}
+*/
+
+	eXosip_register_send_register(reg->regid, msg);
+#else
 	if(eXosip_register(reg->regid, reg->duration / 1000) < 0)
 	{
 		eXosip_unlock();
 		return "cannot register with sip proxy";
 	}
+#endif
 	eXosip_unlock();
 
 	reg->setTimer(reg->duration / 2 - 1000);
@@ -712,7 +739,9 @@ bool Driver::authenticate(Session *s)
 		goto unlock;
 	}
 
+#ifndef	HAVE_EXOSIP2
 	eXosip_retry_call(s->cid);
+#endif
 	rtn = true;
 
 unlock:
@@ -753,7 +782,18 @@ void Driver::refresh(void)
 		slog.debug("refreshing %s", reg->contact);
 
 		eXosip_lock();
+#ifdef	HAVE_EXOSIP2
+		osip_message_t *msg = NULL; 
+		const char *cp = getLast("transport");
+		eXosip_register_build_register(reg->regid, reg->duration / 1000, &msg);
+		if(!stricmp(cp, "tcp"))
+			eXosip_transport_set(msg, "TCP");
+		else if(!stricmp(cp, "tls"))
+			eXosip_transport_set(msg, "TLS");
+		eXosip_register_send_register(reg->regid, msg);		
+#else
 		eXosip_register(reg->regid, reg->duration / 1000);
+#endif
 		eXosip_unlock();
 		reg->setTimer(reg->duration / 2 - 1000);
 	}
@@ -971,6 +1011,7 @@ void Driver::run(void)
 				}
 			}
 
+
 			if(!reg && !scr)
 			{
 				slog.warn("sip: unknown uri %s", sevent->req_uri);
@@ -1064,6 +1105,11 @@ sip404:
                         }
                         session->setConst("session.uri_local", caller);
 
+			if(reg)
+				session->setDTMFMode(reg->dtmf);
+			else
+				session->setDTMFMode(NULL);
+
 			setString(buf, sizeof(buf), sevent->remote_uri);
 			caller = strchr(buf, '<');
 			if(!caller)
