@@ -57,6 +57,73 @@ Session::~Session()
 {
 }
 
+void Session::setDTMFMode(const char *mode)
+{
+	if(!mode)
+	{
+	       	dtmf_inband = Driver::sip.dtmf_inband;
+        	dtmf_payload = Driver::sip.dtmf_payload;  
+		return;
+	}
+
+	if(!stricmp(mode, "2833") || !stricmp(mode, "rtp"))
+		mode = Driver::sip.getLast("dtmf");
+
+	session->setConst("session.sip_dtmf", mode);
+
+	if(atoi(mode) > 0)
+	{
+		dtmf_inband = false;
+		dtmf_payload = atoi(mode);
+	}
+	else if(!stricmp(mode, "info"))
+	{
+		dtmf_inband = false;
+		dtmf_payload = 0;
+	}
+	else
+	{
+                dtmf_inband = Driver::sip.dtmf_inband;
+                dtmf_payload = Driver::sip.dtmf_payload;  
+	}
+}		
+
+#ifdef	HAVE_EXOSIP2
+
+void Session::sendDTMFInfo(char digit, unsigned duration)
+{
+	osip_message_t *message = NULL;
+	char dtmf_body[1000];
+
+        snprintf(dtmf_body, sizeof(dtmf_body) - 1,
+                "Signal=%c\r\nDuration=%d\r\n", digit, duration);  
+
+	eXosip_lock();
+	if(eXosip_call_build_info(did, &message) != 0)
+	{
+		eXosip_unlock();
+		return;
+	}
+
+	osip_message_set_body(message, dtmf_body, strlen(dtmf_body));
+	osip_message_set_content_type(message, "application/dtmf-relay");
+	eXosip_call_send_request(did, message);
+	eXosip_unlock();
+}
+
+#else
+void Session::sendDTMFInfo(char digit, unsigned duration)
+{
+	char dtmf_body[1000];
+	snprintf(dtmf_body, sizeof(dtmf_body) - 1, 
+		"Signal=%c\r\nDuration=%d\r\n", digit, duration);
+        eXosip_lock();
+        eXosip_info_call(did, "application/dtmf-relay", dtmf_body);
+        eXosip_unlock();
+}
+
+#endif
+
 timeout_t Session::getRemaining(void)
 {
 	return TimerPort::getTimer();
@@ -136,6 +203,10 @@ bool Session::enterSeize(Event *event)
 	switch(event->id)
 	{
 	case ENTER_STATE:
+		cp = getSymbol("session.sip_dtmf");
+		if(!cp)
+			setDTMFMode(NULL);
+
 		cp = getSymbol("session.dialed");
 		if(!cp)
 		{
@@ -178,9 +249,14 @@ bool Session::enterSeize(Event *event)
 			{
 				setConst("session.uri_local", reg->uri);
 				from = getSymbol("session.uri_local");
+				setDTMFMode(reg->dtmf);
 			}
+			else
+				setDTMFMode(NULL);
 			endImage(img);
-		}			
+		}		
+		else	
+			setDTMFMode(NULL);
 
 		if(!from)
 		{
