@@ -27,6 +27,8 @@ Runtime::Runtime() :
 ScriptRuntime()
 {
 	static ScriptInterp::Define interp[] = {
+		{"bgm", false, (Method)&Methods::scrBGM,
+			(Check)&Checks::chkBGM},
 		{"config", true, (Method)&ScriptMethods::scrNop,
 			(Check)&Checks::chkConfig},
 		{"dialtone", false, (Method)&Methods::scrTone,
@@ -170,6 +172,7 @@ ScriptRuntime()
 
 	load(interp);
 
+	ScriptInterp::addConditional("number", &testNumber);
 	ScriptInterp::addConditional("file", &testFile);
 	ScriptInterp::addConditional("dir", &testDir);
 	ScriptInterp::addConditional("span", &testSpan);
@@ -319,6 +322,21 @@ bool Runtime::testDriver(ScriptInterp *interp, const char *v)
 	return false;
 }
 
+bool Runtime::testNumber(ScriptInterp *interp, const char *v)
+{
+	if(!v || !*v)
+		return false;
+
+	while(*v)
+	{
+		if(!isdigit(*v) && !ispunct(*v))
+			return false;
+		++v;
+	}
+
+	return true;
+}
+
 bool Runtime::testFile(ScriptInterp *interp, const char *v)
 {
 	BayonneSession *s = (BayonneSession *)(interp);
